Method: Aruba::Processes::SpawnProcess#initialize

Defined in:
lib/aruba/processes/spawn_process.rb

#initialize(cmd, exit_timeout, io_wait_timeout, working_directory, environment = Aruba.platform.environment_variables.hash_from_env, main_class = nil, stop_signal = nil, startup_wait_time = 0) ⇒ SpawnProcess

Create process

Parameters:

  • cmd (String)

    Command string

  • exit_timeout (Numeric)

    The timeout until we expect the command to be finished

  • io_wait_timeout (Numeric)

    The timeout until we expect the io to be finished

  • working_directory (String)

    The directory where the command will be executed

  • environment (Hash) (defaults to: Aruba.platform.environment_variables.hash_from_env)

    Environment variables

  • main_class (Class) (defaults to: nil)

    E.g. Cli::App::Runner

  • stop_signal (String) (defaults to: nil)

    Name of signal to send to stop process. E.g. ‘HUP’.

  • startup_wait_time (Numeric) (defaults to: 0)

    The amount of seconds to wait after Aruba has started a command.



129
130
131
132
133
134
135
136
137
# File 'lib/aruba/processes/spawn_process.rb', line 129

def initialize(cmd, exit_timeout, io_wait_timeout, working_directory, # rubocop:disable Metrics/ParameterLists
               environment = Aruba.platform.environment_variables.hash_from_env,
               main_class = nil, stop_signal = nil, startup_wait_time = 0)
  super

  @process      = nil
  @stdout_cache = nil
  @stderr_cache = nil
end