Module: Aruba::EventBus::NameResolver::ResolveHelpers
- Included in:
- StringResolver, SymbolResolver
- Defined in:
- lib/aruba/event_bus/name_resolver.rb
Overview
Helpers for Resolvers
Instance Method Summary collapse
- #camel_case(underscored_name) ⇒ Object
-
#constantize(camel_cased_word) ⇒ Object
Thanks ActiveSupport (Only needed to support Ruby 1.9.3 and JRuby) rubocop:disable Metrics/CyclomaticComplexity.
Instance Method Details
#camel_case(underscored_name) ⇒ Object
12 13 14 |
# File 'lib/aruba/event_bus/name_resolver.rb', line 12 def camel_case(underscored_name) underscored_name.to_s.split('_').map { |word| word.upcase[0] + word[1..-1] }.join end |
#constantize(camel_cased_word) ⇒ Object
Thanks ActiveSupport (Only needed to support Ruby 1.9.3 and JRuby) rubocop:disable Metrics/CyclomaticComplexity
19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/aruba/event_bus/name_resolver.rb', line 19 def constantize(camel_cased_word) names = camel_cased_word.split('::') # Trigger a built-in NameError exception including the ill-formed constant in the message. Object.const_get(camel_cased_word) if names.empty? # Remove the first blank element in case of '::ClassName' notation. names.shift if names.size > 1 && names.first.empty? names.inject(Object) do |constant, name| if constant == Object constant.const_get(name) else candidate = constant.const_get(name) next candidate if constant.const_defined?(name, false) next candidate unless Object.const_defined?(name) # Go down the ancestors to check if it is owned directly. The check # stops when we reach Object or the end of ancestors tree. constant = constant.ancestors.inject do |const, ancestor| break const if ancestor == Object break ancestor if ancestor.const_defined?(name, false) const end # owner is in Object, so raise constant.const_get(name, false) end end end |