Class: Aruba::Processes::SpawnProcess
- Inherits:
-
BasicProcess
- Object
- BasicProcess
- Aruba::Processes::SpawnProcess
- Defined in:
- lib/aruba/processes/spawn_process.rb
Overview
Spawn a process for command
SpawnProcess is not meant for direct use - SpawnProcess.new - by
users. Only it's public methods are part of the public API of aruba, e.g.
#stdin, #stdout.
Instance Attribute Summary
Attributes inherited from BasicProcess
#environment, #exit_status, #exit_timeout, #io_wait_timeout, #main_class, #startup_wait_time, #stop_signal, #working_directory
Class Method Summary collapse
-
.match?(_mode) ⇒ Boolean
Use as default launcher.
Instance Method Summary collapse
-
#close_io(name) ⇒ Object
Close io.
-
#content ⇒ String
Content of command.
-
#filesystem_status ⇒ Aruba::Platforms::FilesystemStatus
Return file system stats for the given command.
-
#initialize(cmd, exit_timeout, io_wait_timeout, working_directory, environment = Aruba.platform.environment_variables.hash_from_env, main_class = nil, stop_signal = nil, startup_wait_time = 0) ⇒ SpawnProcess
constructor
Create process.
- #interactive? ⇒ Boolean
-
#pid ⇒ Object
Output pid of process.
-
#send_signal(signal) ⇒ Object
Send command a signal.
-
#start {|SpawnProcess| ... } ⇒ Object
Run the command.
-
#stderr(opts = {}) ⇒ String
Access to stderr of process.
-
#stdin ⇒ Object
Access to stdin of process.
-
#stdout(opts = {}) ⇒ String
Access to stdout of process.
-
#stop ⇒ Object
Stop command.
-
#terminate ⇒ Object
Terminate command.
-
#wait ⇒ Object
Wait for command to finish.
- #write(input) ⇒ Object
Methods inherited from BasicProcess
#after_run, #arguments, #before_run, #command, #commandline, #inspect, #output, #restart, #started?, #stopped?, #timed_out?
Constructor Details
#initialize(cmd, exit_timeout, io_wait_timeout, working_directory, environment = Aruba.platform.environment_variables.hash_from_env, main_class = nil, stop_signal = nil, startup_wait_time = 0) ⇒ SpawnProcess
Create process
51 52 53 54 55 56 57 58 59 |
# File 'lib/aruba/processes/spawn_process.rb', line 51 def initialize(cmd, exit_timeout, io_wait_timeout, working_directory, environment = Aruba.platform.environment_variables.hash_from_env, main_class = nil, stop_signal = nil, startup_wait_time = 0) super @process = nil @stdout_cache = nil @stderr_cache = nil end |
Class Method Details
.match?(_mode) ⇒ Boolean
Use as default launcher
22 23 24 |
# File 'lib/aruba/processes/spawn_process.rb', line 22 def self.match?(_mode) true end |
Instance Method Details
#close_io(name) ⇒ Object
Close io
173 174 175 176 177 |
# File 'lib/aruba/processes/spawn_process.rb', line 173 def close_io(name) return if stopped? @process.io.public_send(name.to_sym).close end |
#content ⇒ String
Content of command
259 260 261 |
# File 'lib/aruba/processes/spawn_process.rb', line 259 def content File.read command_path end |
#filesystem_status ⇒ Aruba::Platforms::FilesystemStatus
Return file system stats for the given command
250 251 252 |
# File 'lib/aruba/processes/spawn_process.rb', line 250 def filesystem_status Aruba.platform.filesystem_status.new(command_path) end |
#interactive? ⇒ Boolean
263 264 265 |
# File 'lib/aruba/processes/spawn_process.rb', line 263 def interactive? true end |
#pid ⇒ Object
Output pid of process
This is the PID of the spawned process.
229 230 231 |
# File 'lib/aruba/processes/spawn_process.rb', line 229 def pid @process.pid end |
#send_signal(signal) ⇒ Object
Send command a signal
237 238 239 240 241 242 243 244 |
# File 'lib/aruba/processes/spawn_process.rb', line 237 def send_signal(signal) = %(Command "#{commandline}" with PID "#{pid}" has already stopped.) fail CommandAlreadyStoppedError, if @process.exited? Process.kill signal, pid rescue Errno::ESRCH raise CommandAlreadyStoppedError, end |
#start {|SpawnProcess| ... } ⇒ Object
Run the command
rubocop:disable Metrics/MethodLength
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/aruba/processes/spawn_process.rb', line 67 def start # rubocop:disable Layout/LineLength if started? = %(Command "#{commandline}" has already been started. Please `#stop` the command first and `#start` it again. Alternatively use `#restart`.\n#{caller.join("\n")}) fail CommandAlreadyStartedError, end # rubocop:enable Layout/LineLength @started = true @process = ChildProcess.build(*command_string.to_a) @stdout_file = Tempfile.new('aruba-stdout-') @stderr_file = Tempfile.new('aruba-stderr-') @stdout_file.sync = true @stderr_file.sync = true if RUBY_VERSION >= '1.9' @stdout_file.set_encoding('ASCII-8BIT') @stderr_file.set_encoding('ASCII-8BIT') end @exit_status = nil @duplex = true before_run @process.leader = true @process.io.stdout = @stdout_file @process.io.stderr = @stderr_file @process.duplex = @duplex @process.cwd = @working_directory @process.environment.update(environment) begin Aruba.platform.with_environment(environment) do @process.start sleep startup_wait_time end rescue ChildProcess::LaunchError => e raise LaunchError, "It tried to start #{commandline}. " + e. end after_run yield self if block_given? end |
#stderr(opts = {}) ⇒ String
Access to stderr of process
154 155 156 157 158 159 160 161 |
# File 'lib/aruba/processes/spawn_process.rb', line 154 def stderr(opts = {}) return @stderr_cache if stopped? wait_for_io opts.fetch(:wait_for_io, io_wait_timeout) do @process.io.stderr.flush open(@stderr_file.path).read end end |
#stdin ⇒ Object
Access to stdin of process
119 120 121 122 123 |
# File 'lib/aruba/processes/spawn_process.rb', line 119 def stdin return if @process.exited? @process.io.stdin end |
#stdout(opts = {}) ⇒ String
Access to stdout of process
135 136 137 138 139 140 141 142 |
# File 'lib/aruba/processes/spawn_process.rb', line 135 def stdout(opts = {}) return @stdout_cache if stopped? wait_for_io opts.fetch(:wait_for_io, io_wait_timeout) do @process.io.stdout.flush open(@stdout_file.path).read end end |
#stop ⇒ Object
Stop command
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/aruba/processes/spawn_process.rb', line 180 def stop(*) return @exit_status if stopped? begin @process.poll_for_exit(@exit_timeout) rescue ChildProcess::TimeoutError @timed_out = true end terminate end |
#terminate ⇒ Object
Terminate command
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/aruba/processes/spawn_process.rb', line 198 def terminate return @exit_status if stopped? unless @process.exited? if @stop_signal # send stop signal ... send_signal @stop_signal # ... and set the exit status wait else begin @process.stop rescue Errno::EPERM # This can occur on MacOS nil end end end @exit_status = @process.exit_code @stdout_cache = read_temporary_output_file @stdout_file @stderr_cache = read_temporary_output_file @stderr_file @started = false @exit_status end |
#wait ⇒ Object
Wait for command to finish
193 194 195 |
# File 'lib/aruba/processes/spawn_process.rb', line 193 def wait @process.wait end |
#write(input) ⇒ Object
163 164 165 166 167 168 169 170 |
# File 'lib/aruba/processes/spawn_process.rb', line 163 def write(input) return if stopped? @process.io.stdin.write(input) @process.io.stdin.flush self end |